@@ -244,7 +244,7 @@ impl<'a> Template {
         pkg_manager: PackageManager,
         project_name: &str,
         package_name: &str,
-        alpha: bool,
+        beta: bool,
         mobile: bool,
     ) -> anyhow::Result<()> {
         let manifest_bytes =
@@ -257,9 +257,9 @@ impl<'a> Template {
 
         let lib_name = format!("{}_lib", package_name.replace('-', "_"));
 
-        let alpha_str = alpha.to_string();
+        let beta_str = beta.to_string();
         let manifest_template_data: HashMap<&str, &str> = [
-            ("alpha", alpha_str.as_str()),
+            ("beta", beta_str.as_str()),
             ("pkg_manager_run_command", pkg_manager.run_cmd()),
             ("lib_name", &lib_name),
             ("package_name", package_name),
@@ -275,8 +275,8 @@ impl<'a> Template {
         .into();
 
         let template_data: HashMap<&str, String> = [
-            ("stable", (!alpha).to_string()),
-            ("alpha", alpha_str.clone()),
+            ("stable", (!beta).to_string()),
+            ("beta", beta_str.clone()),
             ("mobile", mobile.to_string()),
             ("project_name", project_name.to_string()),
             ("package_name", package_name.to_string()),
@@ -335,8 +335,8 @@ impl<'a> Template {
                 // conditional files:
                 // are files that start with a special syntax
                 //          "%(<list of flags separated by `-`>%)<file_name>"
-                // flags are supported package managers, stable, alpha and mobile.
-                // example: "%(pnpm-npm-yarn-stable-alpha)%package.json"
+                // flags are supported package managers, stable, beta and mobile.
+                // example: "%(pnpm-npm-yarn-stable-beta)%package.json"
                 name if name.starts_with("%(") && name[1..].contains(")%") => {
                     let mut s = name.strip_prefix("%(").unwrap().split(")%");
                     let (mut flags, name) = (
@@ -345,16 +345,16 @@ impl<'a> Template {
                     );
 
                     let for_stable = flags.contains(&"stable");
-                    let for_alpha = flags.contains(&"alpha");
+                    let for_beta = flags.contains(&"beta");
                     let for_mobile = flags.contains(&"mobile");
 
                     // remove these flags to only keep package managers flags
-                    flags.retain(|e| !["stable", "alpha", "mobile"].contains(e));
+                    flags.retain(|e| !["stable", "beta", "mobile"].contains(e));
 
-                    if ((for_stable && !alpha)
-                        || (for_alpha && alpha && !mobile)
-                        || (for_mobile && alpha && mobile)
-                        || (!for_stable && !for_alpha && !for_mobile))
+                    if ((for_stable && !beta)
+                        || (for_beta && beta && !mobile)
+                        || (for_mobile && beta && mobile)
+                        || (!for_stable && !for_beta && !for_mobile))
                         && (flags.contains(&pkg_manager.to_string().as_str()) || flags.is_empty())
                     {
                         name
